#
# spec file for package beignet
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           beignet
Version:        1.1.2
Release:        3.18
Summary:        Open source implementation of the OpenCL for Intel GPUs
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://01.org/beignet/
Source0:        https://01.org/sites/default/files/%{name}-%{version}-source.tar.gz
Source99:       beignet-rpmlintrc
Patch0:         gcc6-support.patch
Patch1:         llvm38-support.patch
Patch2:         std-isnan-isinf.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  llvm >= 3.3
BuildRequires:  llvm-clang >= 3.3
BuildRequires:  llvm-clang-devel >= 3.3
BuildRequires:  llvm-devel >= 3.3
BuildRequires:  ncurses-devel
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(zlib)
# exclusive to Intel GPU
ExclusiveArch:  %ix86 x86_64

%description
Beignet is an open source implementation of the OpenCL specification - a generic
compute oriented API. This code base contains the code to run OpenCL programs
on Intel GPUs which basically defines and implements the OpenCL host functions
required to initialize the device, create the command queues, the kernels and
the programs and run them on the GPU.

%package devel
Summary:        Open source implementation of the OpenCL for Intel GPUs devel package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       opencl-headers

%description devel
Devel package for Beignet is an open source implementation of the OpenCL
specification - a generic compute oriented API.

%prep
%setup -q -n Beignet-%{version}-Source
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%cmake \
	-DLLVM_INSTALL_DIR=%{_bindir}/ \
	-DCMAKE_BUILD_TYPE=Release
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install
find %{buildroot}%{_includedir}/CL/ -regextype posix-egrep -not -regex ".*(cl_intel.h)" -type f -delete

%files
%defattr(-,root,root)
%doc COPYING README.md
%{_libdir}/beignet/
%{_sysconfdir}/OpenCL/vendors/intel-beignet.icd
%dir %{_sysconfdir}/OpenCL
%dir %{_sysconfdir}/OpenCL/vendors

%files devel
%defattr(-,root,root)
%doc docs/*
%{_includedir}/CL/cl_intel.h

%changelog
* Mon Jul  4 2016 mardnh@gmx.de
- Add patches to support build with GCC6.1
  * gcc6-support.patch
  * llvm38-support.patch
  * std-isnan-isinf.patch
* Sun May  8 2016 mpluskal@suse.com
- Update to 1.1.2
  * Add Broxton support.
  * Add llvm3.7 support.
  * Fix event bugs.
  * Fix the annoying "Failed to release userptr..." error message.
  * Fix printf bugs.
- Drop no longer needed beignet-llvm37.diff
* Fri Dec 18 2015 mpluskal@suse.com
- Update to 1.1.1
  * Dump asm to a file.
  * Use addRemappedFile to avoid creating temporary cl source file.
  * add collectInsnNum to collect block instruction number.
  * Fix piglit clLinkProgram fail.
  * Calculate appropriate timestamps for cl profile.
- Use cmake macros
* Thu Oct 22 2015 normand@linux.vnet.ibm.com
- add ExclusiveArch %%{ix86} x86_64 to avoid build error other archi
* Tue Oct 13 2015 mardnh@gmx.de
- add patch: beignet-llvm37.diff to support llvm 3.7
- add rpmlintrc
* Fri Jul 31 2015 mardnh@gmx.de
- update to version 1.1.0
  The highlighted improvements are as below:
  * Added 6th generation Intel Core Processors (SKL) support.
  * Added 5th generation Intel Atom Processors (BSW) support.
  * Re-implement structurized control flow algorithm.
  * Added half data type support after BDW.
  * Implement a new BTI solution to support dynamic bti.
  * Added extension cl_intel_subgroups support.
  * Replace some built-ins with llvm intrinsic.
  * Add Indirect structure argument read support.
  * Enable cl_khr_spir extension to build and run from SPIR binary.
  * Improvement some opencv test suite performance on all platforms.
  * Several other bug fixes since last release.
- removed patch beignet-icd-name-fix.diff (included upstream)
* Tue Mar 17 2015 mardnh@gmx.de
- update to version 1.0.2
  It's a bug fix release including some bug fixes, minor new
  features and some performance improvements.
  The highlighted improvements are as below:
  * Added LLVM 3.6 support.
  * Fixed a bug in popcount().
  * Refactor the legalize pass and const expression handling.
  * Fixed a bug when hardware is inaccessible.
  * Enabled multiarch 32bit and 64bit coexisting.
  * Implemented some new device side clCopyImage kernels.
  * Optimize clEnqueueCopyImageToBuffer for 16 aligned buffer.
* Mon Jan 19 2015 mardnh@gmx.de
- update to version 1.0.1
  * Enable userptr support by default thus it's possible to achieve zero-copy
  when create a buffer object.
  * Change to use TILING_Y mode on BDW platform which lead to a major performance
  improvement for some cases.
  * Fix one liveness bug which is the last such type of known bug in the
  Gen Backend.
  * Fix some builtin math function's accuracy bugs.
  * Improve the strict mode sin/cos implementation, reduce the instruction count
  from 1700 to 400.
  * Use Clang native sampler and image types, now image/sampler are fully comply
  with OpenCL spec.
  * Fix bugs triggered by some popular applications such as darktable.
  Now darktable works fine on all the supported platforms.
  * Add support for old system which doesn't have c++11 features.
* Sat Nov 15 2014 mardnh@gmx.de
- update to version 1.0.0
- removed patch fix_no-return-in-nonvoid-function-llvm_gen_backend.diff
  since it is now included upstream
* Sat Oct 18 2014 mardnh@gmx.de
- added patch: fix_no-return-in-nonvoid-function-llvm_gen_backend.diff
  to address a build rpm-post build error
  - -----------------------------------------
  E: beignet no-return-in-nonvoid-function
  backend/src/llvm/llvm_gen_backend.cpp:1108
  - -----------------------------------------
- add ncurses-devel to BuildRequires
- added build flags CMAKE_BUILD_TYPE=Release
* Tue Oct  7 2014 mardnh@gmx.de
- initial stable package, version 0.9.3
  based on home:mnhauke:opencl:testing/beignet
